@@ -45,39 +45,10 @@ def pipe(a, b, indent=True):
 
 def archive_tree(dir, archive):
     """Creates a tar.gz archive from a given directory."""
-
-    abspath = os.path.abspath(dir)
-    base_root = None
-    is_top_level = False
-
     with tarfile.open(archive, 'w:gz') as tar:
-
-        for root, _, files in os.walk(abspath):
-
-            # Mark the first pass as the top-level directory.
-            if is_top_level is None:
-                is_top_level = True
-
-            if not base_root:
-                base_root = root
-
-            transposed_base = root[len(base_root)+1:]
-
-            for file in files:
-
-                standard_path = os.path.join(root, file)
-
-                if is_top_level:
-                    transposed_path = file
-                else:
-                    transposed_path = os.path.join(transposed_base, file)
-
-                # Add the file to the archive, with the proper transposed path.
-                tar.add(standard_path, arcname=transposed_path)
-
-            # Close out the top-level directory marker.
-            is_top_level = False
-
+        # do not tar.add(dir) with empty arcname, that will create a "/" entry and tar will complain when extracting
+        for item in os.listdir(dir):
+            tar.add(dir+"/"+item, arcname=item)
 
 def extract_tree(archive, dir):
     """Extract tar.gz archive to a given directory."""
